import click

from upwork_fetcher.config import load_config
from upwork_fetcher.commands import fetch, setup


@click.group()
@click.version_option()
@click.pass_context
def cli(ctx: click.Context):
    config = load_config()
    ctx.obj = config


cli.add_command(fetch)
cli.add_command(setup)


# async def async_main():
#     await cli.main(standalone_mode=False)


# if __name__ == "__main__":
#     import asyncio

#     asyncio.run(async_main())



import json
from pathlib import Path
from typing import Any


CONFIG_DIR = Path.home() / ".upwork_fetcher"
CONFIG_FILE = CONFIG_DIR / "config.json"
# DEFAULT_UPWORK_FETCHER_DIR = Path.home() / ".upwork_fetcher"


def load_config(config_path: Path = CONFIG_FILE):
    if not config_path.exists():
        # os.makedirs(config_path.parent, exist_ok=True)
        CONFIG_DIR.mkdir(parents=True, exist_ok=True)

    if not config_path.exists():
        data = {}
        with open(config_path, "w") as file:
            json.dump(data, file, indent=4)

        # return {"upwork_dir": str(CONFIG_DIR)}
    # print(f"loading config {config_path}")
    with open(config_path, "r") as file:
        return json.load(file)


def save_config(data: dict[str, Any]):

    with open(CONFIG_FILE, "r") as file:
        config = json.loads(file.read())

    # print(f"{data = }")

    config.update(data)

    with open(CONFIG_FILE, "w") as file:
        json.dump(config, file)
